@@ -14,7 +14,7 @@ from omnitools import dt2yyyymmddhhmmss, ApacheHeadersDict, str2html
 
 _SERVER = dict(os.environ)
 for k in _SERVER:
-    if _SERVER[k].startswith("REDIRECT_"):
+    if k.startswith("REDIRECT_"):
         _SERVER[k.replace("REDIRECT_", "")] = _SERVER[k]
 arguments = FieldStorage(environ=os.environ)
 arguments = {k: [_.value for _ in arguments[k]] if isinstance(arguments[k], list) else arguments[k].value for k in arguments}
